#
# spec file for package python-lark-parser
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-lark-parser
Version:        0.8.5
Release:        bp156.3.2
Summary:        A parsing library for Python
License:        MPL-2.0
Group:          Development/Languages/Python
URL:            https://github.com/lark-parser
Source:         https://github.com/lark-parser/lark/archive/%{version}.tar.gz#/lark-%{version}.tar.gz
# extracted test gramars from nearley -> https://github.com/kach/nearley
Source1:        testdata.tar.gz
BuildRequires:  %{python_module Js2Py >= 0.68}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Suggests:       python-Js2Py >= 0.68
%python_subpackages

%description
Lark is a general-purpose parsing library for Python.

With Lark, one can parse any context-free grammar with little code.

%prep
%setup -q -n lark-%{version} -a1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc README.md docs/*
%{python_sitelib}/*

%changelog
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.8.5
  * Updated js2py version (for the optional nearley support)
  * Added the g_regex_flags option, to allow applying flags to all terminals.
  * The standalone parser is now MPL2, instead of GPL. The Mozilla
    Public License is much less restrictive, so this shouldn't affect
    anyone who's already using the standalone parser. But it should
    make it easier for other users to adopt it.
  * The biggest change to this release is a new LALR engine, that is
    capable of dealing with a few edge cases that the previous parser couldn't.
  * Transformers now visit tokens, as well as rules (an alternative to
    lexer_callbacks)
* Sun Oct 27 2019 Lars Vogdt <lars@linux-schulserver.de>
- Update to 0.7.7:
  * Fixed a bug in Earley where running it from different threads
    produced bad results
  * Improved error reporting when using LALR
  * Added 'edit_terminals' option, to allow programmatical manipulation
    of terminals, for example to support keywords in different languages.
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.5:
  * Lark transformers can now visit tokens as wel
  * Fixed long-standing non-determinism and prioritization bugs in Earley.
  * Serialize tool now supports multiple start symbols
  * iter_subtrees, find_data and find_pred methods are now included in standalone parser
  * Bugfixes for the transformer interface, for the custom lexer, for grammar imports, and many more
* Mon Aug 26 2019 John Vandenberg <jayvdb@gmail.com>
- Drop no longer necessary disable_test.patch
- Replace %%doc entry docs/ with docs/* to avoid extra sub-directory
- Added Suggests: python-Js2Py for optional runtime dependency
- Update to v0.7.3
  * Added a new tool called Serialize, that stores Lark's internal
    state as JSON. That will allow for integration with other languages.
  * Minor bugfix regarding line-counting and the \s regex
- from v0.7.2
  * Lark now allows you to specify the start symbol when calling
    Lark.parse() (requires pre-declaration of all possible start states,
    see the start option)
  * Negative priority now allowed in rules and terminals
  * Also includes many minor bugfixes, optimizations, and improvements
    to documentation
* Tue May 21 2019 pgajdos@suse.com
- version update to 0.7.1
    Lark can now serialize its parsers, resulting in simplified stand-alone code.
    Bugfix for v_args (Issue #350)
    Improvements and bugfixes for importing rules from grammar files
    Performance improvement for the reconstructor feature
    New Earley implementation with SPPF support
    Added support for importing rules between grammars. The import mechanism
    is namespace-aware.
    Added the maybe_placeholders option, which causes optionals of the form
    [expr] to return None when not matched, instead of just not appearing.
    (optionals of the form expr? maintain the previous behavior of not
    appearing unless matched)
    Plenty of bugfixes, better errors, and better docs
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Wed Mar 13 2019 Ondřej Súkup <mimi.vx@gmail.com>
- initial commit
- add disable_test.patch - skip test without needed data
